@@ -2,6 +2,7 @@
  * Copyright © 2007,2008 Jaap Haitsma <jaap@haitsma.org>
  * Copyright © 2007-2009 daniel g. siegel <dgsiegel@gnome.org>
  * Copyright © 2008 Ryan zeigler <zeiglerr@gmail.com>
+ * Copyright © 2010 Yuvaraj Pandian T <yuvipanda@yuvi.in>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -26,7 +27,9 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gst/interfaces/xoverlay.h>
+#include <clutter/clutter.h>
 #include <cheese-camera-device.h>
+#include <cheese-effect.h>
 
 G_BEGIN_DECLS
 
@@ -37,23 +40,6 @@ G_BEGIN_DECLS
 #define CHEESE_IS_CAMERA_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), CHEESE_TYPE_CAMERA))
 #define CHEESE_CAMERA_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CHEESE_TYPE_CAMERA, CheeseCameraClass))
 
-typedef enum
-{
-  CHEESE_CAMERA_EFFECT_NO_EFFECT       = (0),
-  CHEESE_CAMERA_EFFECT_MAUVE           = (1 << 0),
-  CHEESE_CAMERA_EFFECT_NOIR_BLANC      = (1 << 1),
-  CHEESE_CAMERA_EFFECT_SATURATION      = (1 << 2),
-  CHEESE_CAMERA_EFFECT_HULK            = (1 << 3),
-  CHEESE_CAMERA_EFFECT_VERTICAL_FLIP   = (1 << 4),
-  CHEESE_CAMERA_EFFECT_HORIZONTAL_FLIP = (1 << 5),
-  CHEESE_CAMERA_EFFECT_SHAGADELIC      = (1 << 6),
-  CHEESE_CAMERA_EFFECT_VERTIGO         = (1 << 7),
-  CHEESE_CAMERA_EFFECT_EDGE            = (1 << 8),
-  CHEESE_CAMERA_EFFECT_DICE            = (1 << 9),
-  CHEESE_CAMERA_EFFECT_WARP            = (1 << 10),
-}
-CheeseCameraEffect;
-
 typedef struct
 {
   GObject parent;
@@ -65,6 +51,7 @@ typedef struct
   void (*photo_saved)(CheeseCamera *camera);
   void (*photo_taken)(CheeseCamera *camera, GdkPixbuf *pixbuf);
   void (*video_saved)(CheeseCamera *camera);
+  void (*state_changed)(CheeseCamera *camera, GstState new_state);
 } CheeseCameraClass;
 
 enum CheeseCameraError
@@ -75,34 +62,39 @@ enum CheeseCameraError
 };
 
 GType         cheese_camera_get_type (void);
-CheeseCamera *cheese_camera_new (GtkWidget *video_window,
-                                 char      *camera_device_name,
-                                 int        x_resolution,
-                                 int        y_resolution);
+CheeseCamera *cheese_camera_new (ClutterTexture *video_texture,
+                                 char           *camera_device_name,
+                                 int             x_resolution,
+                                 int             y_resolution);
 
 const CheeseVideoFormat *cheese_camera_get_current_video_format (CheeseCamera *camera);
 void                     cheese_camera_setup (CheeseCamera *camera, char *udi, GError **error);
 void                     cheese_camera_play (CheeseCamera *camera);
 void                     cheese_camera_stop (CheeseCamera *camera);
-void                     cheese_camera_set_effect (CheeseCamera *camera, CheeseCameraEffect effect);
-void                     cheese_camera_start_video_recording (CheeseCamera *camera, char *filename);
-void                     cheese_camera_stop_video_recording (CheeseCamera *camera);
-gboolean                 cheese_camera_take_photo (CheeseCamera *camera, char *filename);
-gboolean                 cheese_camera_take_photo_pixbuf (CheeseCamera *camera);
-gboolean                 cheese_camera_has_camera (CheeseCamera *camera);
-int                      cheese_camera_get_num_camera_devices (CheeseCamera *camera);
-CheeseCameraDevice *     cheese_camera_get_selected_device (CheeseCamera *camera);
-GPtrArray *              cheese_camera_get_camera_devices (CheeseCamera *camera);
-void                     cheese_camera_set_device_by_dev_file (CheeseCamera *camera, char *file);
-void                     cheese_camera_set_device_by_dev_udi (CheeseCamera *camera, char *udi);
-gboolean                 cheese_camera_switch_camera_device (CheeseCamera *camera);
-GList *                  cheese_camera_get_video_formats (CheeseCamera *camera);
-void                     cheese_camera_set_video_format (CheeseCamera      *camera,
-                                                         CheeseVideoFormat *format);
+void                     cheese_camera_set_effect (CheeseCamera *camera, CheeseEffect *effect);
+void                     cheese_camera_connect_effect_texture (CheeseCamera   *camera,
+                                                               CheeseEffect   *effect,
+                                                               ClutterTexture *texture);
+void                cheese_camera_start_video_recording (CheeseCamera *camera, char *filename);
+void                cheese_camera_stop_video_recording (CheeseCamera *camera);
+gboolean            cheese_camera_take_photo (CheeseCamera *camera, char *filename);
+gboolean            cheese_camera_take_photo_pixbuf (CheeseCamera *camera);
+gboolean            cheese_camera_has_camera (CheeseCamera *camera);
+int                 cheese_camera_get_num_camera_devices (CheeseCamera *camera);
+CheeseCameraDevice *cheese_camera_get_selected_device (CheeseCamera *camera);
+GPtrArray *         cheese_camera_get_camera_devices (CheeseCamera *camera);
+void                cheese_camera_set_device_by_dev_file (CheeseCamera *camera, char *file);
+void                cheese_camera_set_device_by_dev_udi (CheeseCamera *camera, char *udi);
+gboolean            cheese_camera_switch_camera_device (CheeseCamera *camera);
+GList *             cheese_camera_get_video_formats (CheeseCamera *camera);
+void                cheese_camera_set_video_format (CheeseCamera      *camera,
+                                                    CheeseVideoFormat *format);
 gboolean cheese_camera_get_balance_property_range (CheeseCamera *camera,
                                                    gchar *property,
                                                    gdouble *min, gdouble *max, gdouble *def);
 void cheese_camera_set_balance_property (CheeseCamera *camera, gchar *property, gdouble value);
+void cheese_camera_toggle_effects_pipeline (CheeseCamera *camera, gboolean active);
+
 G_END_DECLS
 
 #endif /* __CHEESE_CAMERA_H__ */
